@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 10:51:08
-# @Last Modified time: 2022-11-14 15:50:41
+# @Last Modified time: 2022-11-25 15:26:48
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -32,7 +32,7 @@ class SqlParse(object):
 
     @property
     def sql(self):
-        sql = re.sub('^(--.*?\n){0,}', '', self.orisql.strip() + '\n')
+        sql = re.sub('--.*?\n', '\n', self.orisql.strip() + '\n')
         sql = sql.strip()
         # sql = sql if sql and sql.endswith(';') else sql + ';' if sql else ''
         sql = sql[:-1] if sql and sql.endswith(';') else sql if sql else ''
@@ -43,14 +43,14 @@ class SqlParse(object):
         sql = sql if sql.endswith(';') else sql + ';'
         sql_r1 = re.sub('; *\n', ';\n', sql)  # 处理多余的；
         sql_r2 = re.sub(';$', ';\n', sql_r1)  # 末尾增加'\n'
-        sqls = sql_r2.split(";\n")[:-1]
+        sqls = re.split(';\n', sql_r2)[:-1]
         return sqls
 
     @property
     def comment(self):
-        orisql = self.orisql if self.orisql.endswith(';') else self.orisql + ';'
-        comment = orisql.replace(self.sql, '')
-        comment = re.search('-- *(.*?)$', comment.strip())
+        orisql = self.orisql.strip()
+        orisql = orisql if orisql.endswith(';') else orisql + ';'
+        comment = re.search('^-- *(.*?)\n', orisql)
         comment = comment.group(1) if comment else ''
         return comment.strip()
 
@@ -69,18 +69,52 @@ class SqlParse(object):
     @property
     def tablename(self):
         sql = self.sql
-        tmpcreatet = re.search(rf'create(?: temp| temporary) table (.*?) as', sql)
-        createt = re.search(rf'create table (?:if exists |if not exists )?(.*?){REG_BEHIND}', sql)
+        createt = re.search(rf'create (?:temp |temporary )?table (?:if not exists |if exists )?(.*?){REG_BEHIND}', sql)
         updatet = re.search(rf'update (.*?){REG_BEHIND}', sql)
         deletet = re.search(rf'delete (?:from )?(.*?){REG_BEHIND}', sql)
         insertt = re.search(rf'insert into (.*?){REG_BEHIND}', sql)
         ont = re.search(rf'(?<=on )(.*?){REG_BEHIND}', sql)
         fromt = re.search(rf'select .*? (?<=from )(.*?){REG_BEHIND}', sql, re.S)
         # print(createt, updatet, insertt, ont, fromt)
-        tablename = tmpcreatet or createt or updatet or deletet or insertt or fromt or ont
+        tablename = createt or updatet or deletet or insertt or fromt or ont
         tablename = tablename.group(1) if tablename else sql
         return tablename
 
+    @property
+    def split_withsqls(self):
+        sql = self.sql
+        if not sql.lower().startswith('with'):
+            raise Exception(f"Sql should startswith [with], but startswith [{sql[:4]}] !!!")
+
+        sqls = re.split('(?<=\)),\n+.*?\n*(?=.*?as)', sql)
+        if sqls[-1].startswith('select'):
+            sql_last = sqls[-2] + sqls[-1]
+            sqls = sqls[:-2] + [sql_last]
+        return sqls
+
+    @property
+    def combination_sqls(self):
+        combination_sqls = []
+        sqls = self.split_withsqls
+        length = len(sqls)
+        for i in range(length):
+            sql = sqls[i]
+            tablename = re.search(r'(?:with )?(.*?)(?: as)', sql)
+            tablename = tablename.group(1) if tablename else ''
+            content = f"-- {tablename}_{i:03d}"
+
+            i += 1
+            sqls_front = sqls[:i]
+            sqls_front = ',\n'.join(sqls_front)
+            if i < length:
+                sql_select = f'select * from {tablename}'
+                sqls_front += f"\n{sql_select}"
+
+            sqls_front = f'{content}\n' + f'{sqls_front} limit 10\n'
+            combination_sqls.append(sqls_front)
+
+        return combination_sqls
+
 
 class SqlFileParse(object):
 
@@ -180,13 +214,20 @@ class SqlFileParse(object):
 
         return arguments, content
 
-    def get_filesqls(self, **kwargs):
+    def get_filesqls(self, with_test: bool = False, with_snum: int = 0, **kwargs):
         sqls = {}
         arguments, content = self.replace_params(**kwargs)
         sqls_tmp = re.findall(r'(?<!--)\s*###\s*\n(.*?)###', content, re.S)
         for idx, sql in enumerate(sqls_tmp):
             sqlparser = SqlParse(sql)
-            purpose = f"【{idx+1:0>3d}】{sqlparser.purpose}"
+            purpose = f"【{idx:0>3d}】{sqlparser.purpose}"
             sql = re.sub('--【.*?\n', '', sql.strip())
-            sqls[purpose] = sql
+
+            if with_test:
+                combination_sqls = sqlparser.combination_sqls
+                for idx, sql in enumerate(combination_sqls):
+                    if with_snum <= idx:
+                        sqls[f"{purpose}_{idx:03d}"] = sql
+            else:
+                sqls[purpose] = sql
         return arguments, sqls
